#!/usr/bin/env python3
# -*- coding: utf-8 -*-

# Copyright (C) 2022, Jan-Philipp Litza (PLUTEX) <jpl@plutex.de>.
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc.,
# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.

# modifications by thl-cmk[at]outlook[dot]com
# 2024-04-21: fixed missing FixedValue in import
#             changed Alternative titles to "Upper levels in qps"/"Upper levels in %" to better differentiate between them
#             added explicit unit "%2
#             added ruleset for bakery
#             renamed to unbound.py (from unbound_parameters.py)
#             moved to ~/local/lib/check_mk/gui/plugins/wato/check_parameters (from local/share/check_mk/web/plugins/wato)
# 2024-05-14: separated WATO for bakery and check in two files

from cmk.gui.i18n import _
from cmk.gui.plugins.wato.utils import (
    HostRulespec,
    rulespec_registry,
)
from cmk.gui.cee.plugins.wato.agent_bakery.rulespecs.utils import (
    RulespecGroupMonitoringAgentsAgentPlugins,
)

from cmk.gui.valuespec import (
    Alternative,
    Dictionary,
    FixedValue,
    TextInput,
)


def _parameter_valuespec_unbound_bakery():
    return Alternative(
        title='Unbound',
        elements=[
            Dictionary(
                title='Deploy the unbound agent plugin',
                required_keys=['deploy_plugin'],
                elements=[
                    ('config_file_path',
                     TextInput(
                         title=_('Path of config file'),
                         size=100,
                         allow_empty=False,
                         placeholder='/etc/unbound/unbound.conf',
                     )),
                    ('deploy_plugin',
                     FixedValue(
                         True,
                         title=_('Deploy unbound plugin'),
                         totext='Yes',
                     ))
                ]),
            FixedValue(
                None,
                title=_('Do not deploy the unbound agent plugin'),
                totext=_('The unbound agent plugin will not be deployed')
            ),
        ]
    )


rulespec_registry.register(
    HostRulespec(
        group=RulespecGroupMonitoringAgentsAgentPlugins,
        name='agent_config:unbound',
        valuespec=_parameter_valuespec_unbound_bakery,
    )
)
